@@ -1,5 +1,5 @@
 class AccountNotValidatedError(Exception):
-    """Raised when the account has not been validated yet and there is no ref token."""
+    """Raised when the account has not been validated yet."""
 
     def __init__(self, status: str) -> None:
         """Initialize."""
@@ -9,6 +9,7 @@ class AccountNotValidatedError(Exception):
 
 """ Define package errors """
 
+
 class ApiError(Exception):
     """Raised when MyWaterToronto API request ended in error."""
 
@@ -42,4 +43,4 @@ class ValidateAccountInfoError(Exception):
     def __init__(self, status: str) -> None:
         """Initialize."""
         super().__init__(status)
-        self.status = status
\ No newline at end of file
+        self.status = status
